==> borgbackup_1.4.2.orig.tar.gz: borg-1.4.2/.github/ISSUE_TEMPLATE.md <==
<!--
Thank you for reporting an issue.

*IMPORTANT* – before creating a new issue, please look around:
 - BorgBackup documentation: https://borgbackup.readthedocs.io/en/stable/index.html
 - FAQ: https://borgbackup.readthedocs.io/en/stable/faq.html
 and
 - Open issues in the GitHub tracker: https://github.com/borgbackup/borg/issues

If you cannot find a similar problem, then create a new issue.

Please fill in as much of the template as possible.
-->

## Have you checked the BorgBackup docs, FAQ, and open GitHub issues?

No

## Is this a bug/issue report or a question?

Bug/Issue/Question

## System information. For client/server mode, post info for both machines.

#### Your borg version (borg -V).

#### Operating system (distribution) and version.

#### Hardware/network configuration and filesystems used.

#### How much data is handled by borg?

#### Full borg command line that led to the problem (leave out excludes and passwords).


## Describe the problem you're observing.

#### Can you reproduce the problem? If so, describe how. If not, describe troubleshooting steps you took before opening the issue.

#### Include any warnings/errors/backtraces from the system logs

<!--

If this complaint relates to borg performance, please include CRUD benchmark
results and any steps you took to troubleshoot.
How to run the benchmark: https://borgbackup.readthedocs.io/en/stable/usage/benchmark.html

*IMPORTANT* – Please mark logs and terminal command output, otherwise GitHub will not display them correctly.
An example is provided below.

Example:
```
this is an example of how log text should be marked (wrap it with ```)
```
-->

==> borgbackup2_2.0.0b19.post2.orig.tar.gz: borg-2.0.0b19.post2/.github/ISSUE_TEMPLATE.md <==
<!--
Thank you for reporting an issue.

*IMPORTANT* – Before creating a new issue, please look around:
 - BorgBackup documentation: https://borgbackup.readthedocs.io/en/stable/index.html
 - FAQ: https://borgbackup.readthedocs.io/en/stable/faq.html
 - Open issues in the GitHub tracker: https://github.com/borgbackup/borg/issues

If you cannot find a similar problem, then create a new issue.

Please fill in as much of the template as possible.
-->

## Have you checked the BorgBackup docs, FAQ, and open GitHub issues?

No

## Is this a bug/issue report or a question?

Bug/Issue/Question

## System information. For client/server mode, post info for both machines.

#### Your Borg version (borg -V).

#### Operating system (distribution) and version.

#### Hardware/network configuration and filesystems used.

#### How much data is handled by Borg?

#### Full Borg command line that led to the problem (leave out excludes and passwords).


## Describe the problem you're observing.

#### Can you reproduce the problem? If so, describe how. If not, describe troubleshooting steps you took before opening the issue.

#### Include any warnings/errors/backtraces from the system logs

<!--

If this complaint relates to Borg performance, please include CRUD benchmark
results and any steps you took to troubleshoot.
How to run the benchmark: https://borgbackup.readthedocs.io/en/stable/usage/benchmark.html

*IMPORTANT* – Please mark logs and terminal command output, otherwise GitHub will not display them correctly.
An example is provided below.

Example:
```
this is an example of how log text should be marked (wrap it with ```)
```
-->
